﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Drawing;
using HeuristicLab.Core;

namespace HeuristicLab.BioBoost.Utils {
  public class Util {

    public static double Distance(Point p1, Point p2) {
      return Math.Sqrt(Sqr(p1.X - p2.X) + Sqr(p1.Y - p2.Y));
    }

    public static double Sqr(double x) { return x * x; }

    public static void Shuffle<T>(T[] elements, IRandom random) {
      for (int i = elements.Length - 1; i > 0; i--) {
        // Swap element "i" with a random earlier element (including itself)
        int swapIndex = random.Next(i + 1);
        T temp = elements[swapIndex];
        elements[swapIndex] = elements[i];
        elements[i] = temp;
      }
    }

    public static T[] Clone<T>(T[] t) {
      return (T[]) (t == null ? null : t.Clone());
    }

    public static T Clone<T>(T t) where T : ICloneable {
      return (T) (t == null ? null : t.Clone());
    }

  }
}
